<?php

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use \Exception as Exception;
use Teknisa\MAN\Services\ProdLoja as ProdLojaService;
use Teknisa\MAN\Utilities\Util as Util;


class ImpressoraNF extends Crud {
  
    protected $dataSourceName = 'impressoraNF';
    
    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
      
        $rows = $request->getDataSet()->getRows();
        
        foreach ($rows as $row) {
            $this->validate($row);
        }
        
        parent::save($request, $response);
    }
  
    protected function validate($row) {
        if ( !array_key_exists('NMIMPRESSORA', $row) || !array_key_exists('IDMODEIMPRES', $row))  
            throw \Exception('Alguns campos obrigatórios estão vazios!');
        
        if(empty($row['NMIMPRESSORA']) || empty($row['IDMODEIMPRES'])) 
            throw new \Exception('Alguns campos obrigatórios estão vazios!');
            
        if (!(is_numeric($row['IDMODEIMPRES']))) 
            throw new \Exception('O ID Modelo deve ser informado!'); 
        
        if (! (($row['IDMODEIMPRES']) < 32  && ($row['IDMODEIMPRES']) > 0)) 
            throw new \Exception('O ID Modelo deve estar entre 1 e 32!'); 
            
            
    }
    
    // Returns a dataset of impressoraNF 
        // Searches printers by its CDIMPRESSORA
        // and by its IDMODEIMPRES 
    public function getImpressoraNFById(DTO\Request\Row $request, DTO\Response $response) {
        $filterCriteria = new FilterCriteria('impressoraNF');
        
        $row = $request->getRow();
        
        if($row === null) 
            throw new \Exception('O código da impressora deve ser informado!');
            
        // Searches for a Printer saved with this code 
        $filterCriteria->addCondition('NRORG', FilterCriteria::EQ, $row['NRORG'] );
        $filterCriteria->addCondition('CDIMPRESSORA', FilterCriteria::EQ, $row['CDIMPRESSORA'] );
        $result = $this->dataSourceManager->findBy($filterCriteria)->getRows();
        
        // Searches for this printer's model 
        $filterCriteria = new FilterCriteria('impressoraNF');
        $filterCriteria->addCondition('NRORG', FilterCriteria::EQ, $row['NRORG'] );
        $filterCriteria->addCondition('IDMODEIMPRES', FilterCriteria::EQ, $row['IDMODEIMPRES'] );
        $result = array_merge($result, $this->dataSourceManager->findBy($filterCriteria)->getRows());
        
        // Return the printers found
        $response->addDataSet(new DataSet('impressoraNF', $result));
        
        
    }
    
}
