<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;
use Teknisa\MAN\Factories;
use Teknisa\MAN\Services\NovoCodigo;
use Teknisa\Libs\Util\Environment;


class ParamAutomatizadorService {
	protected $entityManager;
	protected $util;
	protected $environment;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, Utilities\Util $util, Environment $environment)  {
		$this->entityManager = $entityManager;
		$this->util = $util;
		$this->environment = $environment;
	}
	
	public function getNrSequenciaAgenda($cdContadorAgendaODH,$NrOrg,$size){
        return NovoCodigo::geraCodigo($this->entityManager->getConnection(),$cdContadorAgendaODH,$NrOrg,10);
    }
    
	public function findUndiade($rows) {
		$params = array(
			'CDOPERADOR' => $rows['CDOPERADOR'],
			'CDROTINA'   => $rows['CDROTINA'],
			'NRORG' 	 => $rows['NRORG']
		);
		
		$query = "SELECT CDFILIAL, NMFILIAL, CDAGENDAODHAUT, CDROTINA, CDCRON AS DSCRON, CDCRON, NRORG, ENVIAEMAIL, EMAIL AS DSEMAIL
			 FROM
			(SELECT F.NRORG, F.CDFILIAL, F.NMFILIAL, AG.ENVIAEMAIL, AG.EMAIL,  AG.CDAGENDAODHAUT, AG.CDROTINA, (AG.MINUTO || ' ' || AG.HORA || ' ' || AG.DIA || ' ' || AG.MES || ' ' || AG.DIASSEMANA ) AS CDCRON 
			FROM FILIAL F
							JOIN FILIOPER FO ON
			                    FO.CDFILIAL = F.CDFILIAL
							LEFT JOIN AGENDAODHAUTOMATIZADOR AG ON
			                    AG.CDFILIAL = F.CDFILIAL
							WHERE FO.CDOPERADOR = :CDOPERADOR
								AND F.NRORG = :NRORG
								AND F.IDSTATUSBLOQ = 'N'
			                    AND AG.CDROTINA = :CDROTINA
							    AND ( FO.DTVALIDADE IS NULL
							          OR ( TRUNC(FO.DTVALIDADE) >= TRUNC(SYSDATE) ) )
								
								ORDER BY F.CDFILIAL)
								ORDER BY CDFILIAL";

		$filial = $this->entityManager->getConnection()->fetchAll($query, $params);
		return $filial;
	}
	
	public function saveUnidade($rows){
		$arrayCron = explode(' ', $rows['DSCRON']);
		
		$params = array(
			'CDOPERADOR'		 => $this->environment->getCdOperador(),
			'CDAGENDAODHAUT'	 => $rows['CDAGENDAODHAUT'],
			'CDFILIAL'			 => $rows['CDFILIAL'],
			'CDROTINA'  		 => $rows['CDROTINA'],
			'NRORG' 			 => $rows['NRORG'],
			'DSEMAIL'  			 => $rows['DSEMAIL'],
			'ENVIAEMAIL' 		 => $rows['ENVIAEMAIL'],
			'MINUTO'  			 => $arrayCron[0],
			'HORA'  			 => $arrayCron[1],
			'DIA'  				 => $arrayCron[2],
			'MES'  				 => $arrayCron[3],
			'DIASSEMANA'  		 => $arrayCron[4]
		);
		return $this->entityManager->getConnection()->executeQuery(self::UPDATE_AGENDAODH, $params);
		
	}
	
	public function saveUnidadeCadAuto($rows){
		$arrayCron = explode(' ', $rows['DSCRON']);
		
		foreach($rows['CDFILIAL'] as $cdfilial){
			$params = array(
				'CDAGENDAODHAUT'	 => $this->getNrSequenciaAgenda( 'MOVCAIXA',$rows['NRORG'],10),
				'CDOPERADOR'		 => $this->environment->getCdOperador(),
				'CDFILIAL'			 => $cdfilial,
				'CDROTINA'  		 => $rows['CDROTINA'],
				'NRORG' 			 => $rows['NRORG'],
				'DSEMAIL'  			 => $rows['DSEMAIL'],
				'ENVIAEMAIL' 		 => $rows['ENVIAEMAIL'],
				'MINUTO'  			 => $arrayCron[0],
				'HORA'  			 => $arrayCron[1],
				'DIA'  				 => $arrayCron[2],
				'MES'  				 => $arrayCron[3],
				'DIASSEMANA'  		 => $arrayCron[4]
			);
			$this->entityManager->getConnection()->executeQuery(self::INSERT_AGENDAODH, $params);
		}
		return [];
	}
	
	public function deleteUnidadeCadAuto($rows){
		foreach($rows['CDFILIAL'] as $cdfilial){
			$params = array(
					'CDFILIAL'			 => $cdfilial,
					'CDROTINA'  		 => $rows['CDROTINA'],
					'NRORG' 			 => $rows['NRORG']
				);
			 $this->entityManager->getConnection()->executeQuery(self::DELETE_AGENDAODH, $params);
		}
		
		return [];
	}
	
	public function deleteUnidade($rows){
		foreach($rows as $unidade){
			$params = array(
					'CDFILIAL'			 => $unidade['CDFILIAL'],
					'CDROTINA'  		 => $unidade['CDROTINA'],
					'NRORG' 			 => $unidade['NRORG']
				);
			 $this->entityManager->getConnection()->executeQuery(self::DELETE_AGENDAODH, $params);
		}
		return [];
	}
	
	const INSERT_AGENDAODH = "
		INSERT INTO AGENDAODHAUTOMATIZADOR
			(CDFILIAL, CDROTINA, CDAGENDAODHAUT, NRORG, MINUTO, EMAIL, ENVIAEMAIL, HORA, DIA, MES, DIASSEMANA, DTINCLUSAO, DTULTATU, CDOPERINCLUSAO, CDOPERULTATU,  NRORGINCLUSAO, NRORGULTATU)
			VALUES
			(:CDFILIAL, :CDROTINA, :CDAGENDAODHAUT, :NRORG, :MINUTO, :DSEMAIL, :ENVIAEMAIL, :HORA, :DIA, :MES, :DIASSEMANA, SYSDATE, SYSDATE, :CDOPERADOR, :CDOPERADOR, :NRORG, :NRORG)";
	
	const UPDATE_AGENDAODH = "
		UPDATE AGENDAODHAUTOMATIZADOR
			SET MINUTO		 = :MINUTO,
				HORA		 = :HORA,
				DIA 		 = :DIA,
				MES 		 = :MES,
				DIASSEMANA	 = :DIASSEMANA,
				CDOPERULTATU = :CDOPERADOR,
				ENVIAEMAIL   = :ENVIAEMAIL,
				EMAIL 	 = :DSEMAIL,
				NRORGULTATU  = :NRORG,
				DTULTATU     = SYSDATE
			WHERE CDFILIAL			= :CDFILIAL AND
				  CDROTINA			= :CDROTINA AND
				  CDAGENDAODHAUT	= :CDAGENDAODHAUT AND
				  NRORG 			= :NRORG";
	
	const DELETE_AGENDAODH = "
		DELETE FROM AGENDAODHAUTOMATIZADOR
			WHERE CDFILIAL			= :CDFILIAL AND
				  CDROTINA			= :CDROTINA AND
				  NRORG 			= :NRORG";

}